.. currentmodule:: message_ix_models.project

Specific research projects (:mod:`.project`)
********************************************

.. automodule:: message_ix_models.project
   :members:


.. currentmodule:: message_ix_models.project.ssp

Shared Socioeconomic Pathways (:mod:`.project.ssp`)
===================================================

.. automodule:: message_ix_models.project.ssp
   :members:
